###############################################################################
# AUTHOR(DATE):       Agurtzane Urtizberea, Dorleta Garcia and Sonia Sanchez
# RESEARCH INSTITUTE: AZTI-TECNALIA                      
# TITLE:        Test Case: 2stock and 2 fleets
# NOTE #1:     
# NOTE #2:      Create FLBEIA input objects and run FLBEIA
###############################################################################

#-------------------------------------------------------------------------------
#   Section 1:       Charge libraries
#   Section 2:       Set directory
#   Section 3:       Load the data
#   Section 4:       Set Simulation-time parameters
#                          first.yr      <- first year of historic data
#                          proj.yr       <- first year of projection
#                          last.yr       <- last year of projection
#   Section 5:       Set names, age, dimensions 
#                          fls           <- fleets' names                                    #vector
#                          stks          <- stocks' names                                    #vector
#                          fl1.mets      <- metiers' names in fleet 'fl1'                    #vector
#                          fl1.met1.stks <- stocks' names in metier 'met1' and fleet 'fl1'   #vector
#                       all stocks:
#                           ni           <- number of iterations
#                           ns           <- number of seasons
#                       stock 'stk1':
#                           stk1.age.min  <- minimum age 
#                           stk1.age.max  <- maximum age
#                           stk1.unit     <- number units
#                       stock 'stk2':
#   Section 6:       biological data
#                       Historical data:
#                         Stock 'stk1':                           
#                           stk1_n.flq     <- Abundance at age     #FLQuant[na,ny(hist),1/nu(stock),ns,1/ni]
#                           stk1_m.flq     <- Natural mortality    #FLQuant[na,ny(hist),1/nu(stock),ns,1/ni]
#                           stk1_spwn.flq  <- Spawning             #FLQuant[na,ny(hist),1/nu(stock),ns,1/ni]
#                           stk1_fec.flq   <- Fecundity            #FLQuant[na,ny(hist),1/nu(stock),ns,1/ni]
#                           stk1_wt.flq    <- Weight               #FLQuant[na,ny(hist),1/nu(stock),ns,1/ni]
#                           stk1_range.min       <- minimum age
#                           stk1_range.max       <- maximum age
#                           stk1_range.plusgroup <- plusgroup
#                           stk1_range.minyear   <- minimum year
#                           stk1_range.minfbar   <- minimum age to take into account in the age 'f' calculation
#                           stk1_range.maxfbar   <- maximum age to take into account in the age 'f' calculation
#                         stock 'stk2': 
#                       Projection parameters: in some variables, the projection is assumed the average of some historical years
#                         stock 'stk1': 
#                           stk1_biol.proj.avg.yrs <- a vector with the years to calculate the average
#                         stock 'stk2': 
#   Section 7:          Historical data per fleet:
#                         Fleet 'fl1' 
#                           fl1.effort.flq        <- Effort          #FLQuant[1,ny(hist),1,ns,1/ni]
#                           fl1.capacity.flq      <- Capacity        #FLQuant[1,ny(hist),1,ns,1/ni](not required)
#                         Historical data per fleet and metier:
#                           Fleet 'fl1' and metier 'met1' 
#                             fl1.met1.effshare.flq <-Effort share                  #FLQuant[1,ny(hist),1,ns,1/ni]
#                             fl1.met1.vcost.flq    <- Variable cost                #FLQuant[1,ny(hist),1,ns,1/ni](not required)
#                           Historical data per fleet,metier and stock:
#                             Fleet 'fl1', metier 'met1' and stock 'stk1':
#                               fl1.met1.stk1_landings.n.flq    <- Landings at age of the stock      #FLQuant[na,ny(hist),1/nu(stock),ns,1/ni]
#                               fl1.met1.stk1_discards.n.flq    <- Discards at age of the stock      #FLQuant[na,ny(hist),1/nu(stock),ns,1/ni]
#                               fl1.met1.stk1_price.flq         <- Price of the stock                #FLQuant[na,ny(hist),1/nu(stock),ns,1/ni] (not required)
#                               fl1.met1.stk1_alpha.flq     <- alpha Cobb-Douglas parameter values   #FLQuant[na,ny,1/nu(stock),ns,1/ni] (not required)
#                               fl1.met1.stk1_beta.flq      <- beta Cobb-Douglas parameter values    #FLQuant[na,ny,1/nu(stock),ns,1/ni] (not required)
#                               fl1.met1.stk1_catch.q.flq   <- catch.q Cobb-Douglas parameter values #FLQuant[na,ny,1/nu(stock),ns,1/ni] (not required)
#                       Projection parameters: in some variables, the projection is assumed the average of some historical years
#                         fleet 'fl1'
#                           fl1_proj.avg.yrs           <-  a vector with the years to calculate the average,            
#                                                          of the next variables; effort, capacity,crewshare      
#                           fleet 'fl1' and metier 'met1':
#                           fl1.met1_proj.avg.yrs      <- a vector with the years to calculate the average,   
#                                                          of the next variables: vcost, effshare                       
#                           fl1.met1.stk1_proj.avg.yrs <- a vector with the years to calculate the average,
#                                                         of the next variables; price,landings.sel,discards.sel,
#                                                         landings.wt, discards.wt,alpha,beta,catch.q
#                         fleet 'fl2'
#  Section 8:       SRs
#                      stk1_sr.model        <- name of the SR model
#                      stk1_param.n         <- number of parameters in the SR model
#                      stk1_params.array    <- Parameters of the model      # array[param.n, ny, ns, ni]   
#                      stk1_params.name     <- Parameters' names
#                      stk1_rec.flq         <- Recruitment                  #FLQuant[1,ny(hist),1/nu(stock),ns,1/ni]
#                      stk1_ssb.flq         <- ssb                          #FLQuant[1,ny(hist),1/nu(stock),ns,1/ni]
#                      stk1_uncertainty.flq <- uncertainty of the model     #FLQuant[na,ny,1/nu(stock),ns,1/ni] (not required)
#                      stk1_proportion.flq  <- proportion of the model      #FLQuant[na,ny,1/nu(stock),ns,1/ni]
#                      stk1_prop.avg.yrs    <- a vector with the years to calculate the average of proportion
#                      stk1_timelag.matrix  <- timelag of year and season of spawning  #matrix(c(0,1),2,ns, dimnames = list(c('year', 'season'),season = 1:ns)) 
#  Section 9:       BDs
#                      stk2_bd.model        <- Biomass dynamic model
#                      stk2_param.n         <- Number of parameters in the model
#                      stk2_params.array    <- Parameters of the model          # array[param.n, ny, ns, ni]   
#                      stk2_params.name     <- Parameters' names
#                      stk2_biomass.flq     <- Biomass                          #FLQuant[1,ny(hist),1/nu(stock),ns,1/ni]
#                      stk2_catch.flq       <- Catch                            #FLQuant[1,ny(hist),1/nu(stock),ns,1/ni]
#                      stk2_uncertainty.flq <- Uncertainty of the model         #FLQuant[1,ny,1/nu(stock),ns,1/ni]   (not required)
#  Section 10:       advice:TAC/TAE/quota.share                                 
#                      stk1_advice.TAC.flq  <- TAC                #FLQuant[1,ny,1,1,1/ni]
#                      Projection:
#                      stk1_advice.avg.yrs  <-a vector with the years to calculate the average of (TAC/quota.share, if they are not defined)
#  Section 11:       main.ctrl
#                      main.ctrl           <- it's a list
#                      main.ctrl$sim.years <- a vector with the 'initial' and 'final' simulation year
#  Section 12:       biols.ctrl
#                      growth.model     <- growth model 
#                      biols.ctrl       <- biols.ctrl object
#  Section 13:       fleets.ctrl
#                      n.flts.stks      <- number of stks per fleet
#                      flts.stksnames   <- stocks' names in each fleet
#                      effort.models    <- effort model per fleet
#                      effort.restr.fl2 <- stock restricting the effort in fl2 fleet 
#                      restriction.fl2  <- restricting the effort in fl2 fleet options: 'catch',...
#                      catch.models     <- catch  model per fleet
#                      capital.models   <- capital model per fleet
#                      price.models     <- elastic price  
#                      flq     <- FLQuant with the dimenstions of the stock. Required by fleets.ctrl                 
#                      fleets.ctrl      <- fleets ctrl object  
#  Section 14:       advice.ctrl
#                      HCR.models       <- HCR model per stock 
#                      Ftarget.stk2     <- 'stk2' stock's f target
#                      ref.pts.stk1     <- 'stk1' stock's reference points
#                      advice.ctrl      <- advice ctrl object
#  Section 15:       assess.ctrl
#                      assess.models    <- assessment model per fleet
#                      assess.ctrl      <- assess.ctrl object
#  Section 16:       obs.ctrl
#                      stkObs.models    <- Observation model per stock
#                      obs.ctrl         <- obs.ctrl object
#  Section 17:       covars.ctrl
#                      covars.ctrl      <- NULL
#  Section 18:       FLBEIA input objects
#  Section 19:       Run FLBEIA
#  Section 20:       Plot
#------------------------------------------------------------------------------#

rm(list=ls())

#==============================================================================
# Section 1:            Charge libraries
#==============================================================================

  library(FLCore) 
  library(FLAssess)
  library(FLash)
  library(FLFleet)
  library(FLXSA)
  library(FLBEIA) 

#==============================================================================
# Section 2:            Set directory and Load the data
#==============================================================================

#wd <- ''
#setwd(wd)



#==============================================================================
# Section 3:            Load the data
#==============================================================================

  #load('2stock2fleets4seasons/data/input_data.RData')

#==============================================================================
# Section 4:            Set Simulation parameters related with time
#==============================================================================
  
  first.yr          <- 1990
  proj.yr           <- 2009 
  last.yr           <- 2025  

#==============================================================================
#  Section 5:       Set names, age, dimensions 
#==============================================================================
  
  fls   <- c('fl1','fl2')

  stks <- c('stk1','stk2')

  fl1.mets      <- c('met1','met2')
  fl1.met1.stks <- c('stk1','stk2')
  fl1.met2.stks <- c('stk1','stk2')

  fl2.mets      <- c('met1','met2')
  fl2.met1.stks <- c('stk1','stk2')
  fl2.met2.stks <- c('stk1','stk2')

  # all stocks the same
  ni             <- 1
  ns             <- 4
  
  # stock stk1
  stk1.age.min    <- 0
  stk1.age.max    <- 15
  stk1.unit       <- 4         
  
  # stock stk2
  stk2.age.min    <- 1
  stk2.age.max    <- 1
  stk2.unit       <- 1         

#==============================================================================
# Section 6:            biols
#==============================================================================
#  Historical data
#  stk1_n.flq, m, spwn, fec, wt
#==============================================================================

  #stock stk1
  stk1_n.flq     <- as.FLQuant(read.csv(file = 'data/stk1_n.csv'))
  stk1_m.flq     <- as.FLQuant(read.csv(file = 'data/stk1_m.csv'))
  stk1_spwn.flq  <- as.FLQuant(read.csv(file = 'data/stk1_spwn.csv'))
  stk1_fec.flq   <- as.FLQuant(read.csv(file = 'data/stk1_fec.csv'))
  stk1_wt.flq    <- as.FLQuant(read.csv(file = 'data/stk1_wt.csv'))
  
  stk1_range.min       <- 0
  stk1_range.max       <- 15
  stk1_range.plusgroup <- 15
  stk1_range.minyear   <- 1990
  stk1_range.minfbar   <- 1
  stk1_range.maxfbar   <- 5

# stock stk2

  stk2_n.flq     <- as.FLQuant(read.csv(file = 'data/stk2_n.csv'))
  stk2_m.flq     <- as.FLQuant(read.csv(file = 'data/stk2_m.csv'))
  stk2_spwn.flq  <- as.FLQuant(read.csv(file = 'data/stk2_spwn.csv'))
  stk2_fec.flq   <- as.FLQuant(read.csv(file = 'data/stk2_fec.csv'))
  stk2_wt.flq    <- as.FLQuant(read.csv(file = 'data/stk2_wt.csv'))

  stk2_range.min       <- 1
  stk2_range.max       <- 1
  stk2_range.plusgroup <- 1
  stk2_range.minyear   <- 1990
  stk2_range.minfbar   <- 1
  stk2_range.maxfbar   <- 1

#               Projection: 
#  we assume that the projection values of some variables are equal to 
#  the average of some historical years:weight,fecundity,mortality and spawning    
  
  stk1_biol.proj.avg.yrs  <- c(2006:2008)
  stk2_biol.proj.avg.yrs  <- c(2006:2008)

    
    #==============================================================================
    #              FLBEIA input object: biols
    #==============================================================================
    
    biols    <- create.biols.data()
     
    plot.biols(biols,'s0')

#==============================================================================
# Section 7:            fleets
#==============================================================================
# Data per fleet
#    effort, crewshare, fcost, capacity
# Data per fleet and metier
#    effshare, vcost
# Data per fleet, metier and stock
#    landings.n, discards.n,landings.wt, discards.wt, landings, discards, landings.sel, discards.sel, price
#==============================================================================
          
          fl1_effort.flq        <- as.FLQuant(read.csv(file = 'data/fl1_effort.csv'))
          fl1_capacity.flq      <- as.FLQuant(read.csv(file = 'data/fl1_capacity.csv'))
          fl1.met1_effshare.flq <- as.FLQuant(read.csv(file = 'data/fl1.met1_effshare.csv'))
          fl1.met2_effshare.flq <- as.FLQuant(read.csv(file = 'data/fl1.met2_effshare.csv'))

          fl1.met1.stk1_landings.n.flq <- as.FLQuant(read.csv(file = 'data/fl1.met1.stk1_landings.n.csv'))
          fl1.met1.stk1_discards.n.flq <- as.FLQuant(read.csv(file = 'data/fl1.met1.stk1_discards.n.csv'))
          fl1.met1.stk2_landings.n.flq <- as.FLQuant(read.csv(file = 'data/fl1.met1.stk2_landings.n.csv'))
          fl1.met1.stk2_discards.n.flq <- as.FLQuant(read.csv(file = 'data/fl1.met1.stk2_discards.n.csv'))

          fl1.met2.stk1_landings.n.flq <- as.FLQuant(read.csv(file = 'data/fl1.met2.stk1_landings.n.csv'))
          fl1.met2.stk2_landings.n.flq <- as.FLQuant(read.csv(file = 'data/fl1.met2.stk2_landings.n.csv'))

          fl2_effort.flq   <- as.FLQuant(read.csv(file = 'data/fl2_effort.csv'))
          fl2_capacity.flq <- as.FLQuant(read.csv(file = 'data/fl2_capacity.csv'))
          fl2_fcost.flq    <- as.FLQuant(read.csv(file = 'data/fl2_fcost.csv'))

          fl2.met1_effshare.flq <- as.FLQuant(read.csv(file = 'data/fl2.met1_effshare.csv'))
          fl2.met2_effshare.flq <- as.FLQuant(read.csv(file = 'data/fl2.met2_effshare.csv')) 
          fl2.met1_vcost.flq    <- as.FLQuant(read.csv(file = 'data/fl2.met1_vcost.csv'))
          fl2.met2_vcost.flq    <- as.FLQuant(read.csv(file = 'data/fl2.met2_vcost.csv'))

          fl2.met1.stk1_landings.n.flq <- as.FLQuant(read.csv(file = 'data/fl2.met1.stk1_landings.n.csv'))
          fl2.met2.stk1_landings.n.flq <- as.FLQuant(read.csv(file = 'data/fl2.met2.stk1_landings.n.csv'))
          fl2.met1.stk2_landings.n.flq <- as.FLQuant(read.csv(file = 'data/fl2.met1.stk2_landings.n.csv'))
          fl2.met2.stk2_landings.n.flq <- as.FLQuant(read.csv(file = 'data/fl2.met2.stk2_landings.n.csv'))
          fl2.met1.stk1_discards.n.flq <- as.FLQuant(read.csv(file = 'data/fl2.met1.stk1_discards.n.csv'))
          fl2.met2.stk1_discards.n.flq <- as.FLQuant(read.csv(file = 'data/fl2.met2.stk1_discards.n.csv'))
          fl2.met1.stk2_discards.n.flq <- as.FLQuant(read.csv(file = 'data/fl2.met1.stk2_discards.n.csv'))
          fl2.met2.stk2_discards.n.flq <- as.FLQuant(read.csv(file = 'data/fl2.met2.stk2_discards.n.csv'))

#         Projection
#==============================================================================
#         fleets: fl1
#==============================================================================

          fl1_proj.avg.yrs           <- c(2003:2005)
          fl1.met1_proj.avg.yrs      <- c(2003:2005)   
          fl1.met2_proj.avg.yrs      <- c(2003:2005)   

          fl1.met1.stk1_proj.avg.yrs <- c(2003:2005)  
          fl1.met1.stk2_proj.avg.yrs <- c(2003:2005)

          fl1.met2.stk1_proj.avg.yrs <- c(2003:2005)  
          fl1.met2.stk2_proj.avg.yrs <- c(2003:2005)

#==============================================================================
#         fleets: fl2
#==============================================================================

          fl2_proj.avg.yrs           <- c(2005,2007,2008)
          fl2.met1_proj.avg.yrs      <- c(2005,2007,2008)
          fl2.met2_proj.avg.yrs      <- c(2005,2007,2008)

          fl2.met1.stk1_proj.avg.yrs <- c(2005,2007,2008)
          fl2.met2.stk1_proj.avg.yrs <- c(2005,2007,2008)

          fl2.met1.stk2_proj.avg.yrs <- c(2005,2007,2008)
          fl2.met2.stk2_proj.avg.yrs <- c(2005,2007,2008)
          
          #==============================================================================
          #              FLBEIA input object: fleets
          #==============================================================================
          
          fleets   <- create.fleets.data()
            plot.fleets(fleets,'s0')   

#==============================================================================
#  Section 8:       SRs
#==============================================================================

     stk1_sr.model        <- 'bevholt'
     stk1_params.n        <- 2
     stk1_params.array    <- xtabs2(data~param+year+season+iter, 
                                               data=read.csv(file = 'data/stk1_params.csv'),exclude=NULL,na.action=na.pass)           
     stk1_params.name     <- c('a','b') 
     stk1_rec.flq         <- as.FLQuant(read.csv(file = 'data/stk1_rec.csv'))             
     stk1_ssb.flq         <- as.FLQuant(read.csv(file = 'data/stk1_ssb.csv'))             
     stk1_uncertainty.flq <- as.FLQuant(read.csv(file = 'data/stk1_uncertainty.csv'))     
     stk1_proportion.flq  <- as.FLQuant(read.csv(file = 'data/stk1_proportion.csv'))      
     stk1_prop.avg.yrs    <- ac(2006:2008)
     stk1_timelag.matrix  <- matrix(c(0,1),2,ns, dimnames = list(c('year', 'season'),season = 1:ns)) 

    #==============================================================================
    #              FLBEIA input object: SRs
    #==============================================================================
    SRs      <- create.SRs.data()
    
#==============================================================================
#  Section 9:       BDs
#==============================================================================
     stk2_bd.model        <- 'PellaTom'
     stk2_param.n         <- 3
     stk2_params.name     <- c('K','p','r') 
     stk2_params.array    <- xtabs2(data~param+year+season+iter, 
                                    data=read.csv(file = 'data/stk2_params.csv'),exclude=NULL,na.action=na.pass)              
     stk2_biomass.flq     <- as.FLQuant(read.csv(file = 'data/stk2_biomass.csv'))            
     stk2_catch.flq       <- as.FLQuant(read.csv(file = 'data/stk2_catch.csv'))               
     stk2_uncertainty.flq <- as.FLQuant(read.csv(file = 'data/stk2_uncertainty.csv'))          

    
    #==============================================================================
    #              FLBEIA input object: BDs
    #==============================================================================
    
    BDs       <- create.BDs.data()

#==============================================================================
#  Section 10:       advice:TAC/TAE/quota.share
#==============================================================================

    stk1_advice.TAC.flq   <- as.FLQuant(read.csv(file = 'data/stk1.tac.csv'))
    stk1_advice.avg.yrs   <- c(2006:2008)

    stk2_advice.TAC.flq   <- as.FLQuant(read.csv(file = 'data/stk2.tac.csv'))
    stk2_advice.avg.yrs   <- c(2006:2008)
    
    
    #==============================================================================
    #              FLBEIA input object: advice
    #==============================================================================
    
    advice   <- create.advice.data()

#==============================================================================
#  Section 11:       main.ctrl
#==============================================================================

    main.ctrl           <- list()
    main.ctrl$sim.years <- c(initial = proj.yr, final = last.yr)

#==============================================================================
#  Section 12:       biols.ctrl
#==============================================================================

    growth.model     <- c('ASPG','BDPG')
    biols.ctrl       <- create.biols.ctrl (stksnames=stks,growth.model=c('ASPG','BDPG'))

#==============================================================================
#  Section 13:       fleets.ctrl
#==============================================================================

    n.flts.stks      <- c(2,2)
    flts.stksnames   <- rep(c('stk1','stk2'),2)
    effort.models    <- c('fixedEffort','SMFB')
    effort.restr.fl2 <- 'min'
    restriction.fl2  <- 'catch'
    catch.models     <- rep(c("CobbDouglasAge", "CobbDouglasBio"),2)
    capital.models   <- rep('fixedCapital',2)
    price.models     <- NULL                            
   
    flq              <- create.list.stks.flq ()[['stk1']][,,1,]  
    fleets.ctrl      <- create.fleets.ctrl(fltsnames=fls,n.flts.stks=n.flts.stks,flts.stksnames=flts.stksnames,
                                           effort.models= effort.models, catch.models=catch.models,
                                           capital.models=capital.models, price.models=price.models,flq=flq,
                                           effort.restr.fl2 = effort.restr.fl2, restriction.fl2 = restriction.fl2)

#==============================================================================
#  Section 14:       advice.ctrl
#==============================================================================


    HCR.models       <- c('IcesHCR','annualTAC') 
    Ftarget.stk2     <- 0.3
    ref.pts.stk1     <- matrix(c(0.24, 50000, 150000), 3,ni, dimnames = list(c('Fmsy', 'Blim', 'Btrigger'), 1:ni))
    
    advice.ctrl      <- create.advice.ctrl(stksnames = stks, HCR.models =  HCR.models, 
                        ref.pts.stk1 = ref.pts.stk1, Ftarget.stk2 = Ftarget.stk2)

    advice.ctrl[['stk1']][['sr']]            <- list()
    advice.ctrl[['stk1']][['sr']][['model']] <- 'segreg'
    advice.ctrl[['stk1']][['sr']][['years']] <- c(y.rm = 2, num.years = 10)
    advice.ctrl$stk1$AdvCatch <- rep(TRUE,length(first.yr:last.yr))   #TRUE advice in catches, FALSE advice in landings
    names(advice.ctrl$stk1$AdvCatch) <- as.character((first.yr:last.yr))

#==============================================================================
#  Section 15:       assess.ctrl
#==============================================================================

    assess.models    <- rep('NoAssessment',2)
    
    assess.ctrl      <- create.assess.ctrl(stksnames = stks, assess.models = assess.models)

#==============================================================================
#  Section 16:       obs.ctrl
#==============================================================================

    stkObs.models    <- rep('perfectObs',2)
    
    obs.ctrl         <- create.obs.ctrl(stksnames = stks,  stkObs.models = stkObs.models)

#==============================================================================
#  Section 17:       covars.ctrl
#==============================================================================

    covars.ctrl      <- NULL
  
#==============================================================================
#  Section 18:       FLBEIA input objects
#==============================================================================
    
      
    covars <- NULL
    
    indices <- NULL

#==============================================================================
#       Plot input objects: biols and fleets
#==============================================================================

#==============================================================================
#  Section 19:       Run FLBEIA
#==============================================================================
save(biols, SRs,BDs, fleets, covars, 
     indices, advice, main.ctrl, 
     biols.ctrl, fleets.ctrl, 
     covars.ctrl, obs.ctrl, 
     assess.ctrl, advice.ctrl, file="input_S0.RData")


    s0 <- FLBEIA(biols = biols, SRs = SRs, BDs = BDs, fleets=fleets, covars = covars, 
              indices = indices, advice = advice, main.ctrl = main.ctrl, 
              biols.ctrl = biols.ctrl, fleets.ctrl = fleets.ctrl, 
              covars.ctrl = covars.ctrl, obs.ctrl = obs.ctrl, 
              assess.ctrl = assess.ctrl, advice.ctrl = advice.ctrl) 


save(s0,file='s0_results.RData')

#==============================================================================
#  Section 20:       Plot
#==============================================================================
    
names(s0)

s0_sum      <- bioSum(s0)
s0_eco      <- ecoSum(s0$fleets, flnms='all', years=ac((proj.yr+1):last.yr))
s0_catchFl  <- catchFlSum(s0$fleets,s0$advice,flnms= 'all',stknms= 'all', years=ac((proj.yr+1):last.yr))
s0_M <- aggregate(value ~ year+indicator, data = s0_sum, median)

plot.biols(s0$biols,'s0')
plot.fleets(s0$fleets,'s0')
plot.catchFl(s0$fleets,s0$advice,'s0') 
plot.eco(s0$fleets,'s0')


  